#
# spec file for package opi
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define use_python python3
%define pythons %{use_python}

Name:           opi
Version:        5.8.1
Release:        1.1
Summary:        OBS Package Installer (CLI)
License:        GPL-3.0-only
Group:          System/Packages
URL:            https://github.com/openSUSE/opi
Source0:        https://github.com/openSUSE/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildArch:      noarch

BuildRequires:  %{python_module base >= 3.6}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros

BuildRequires:  distribution-release
BuildRequires:  help2man
BuildRequires:  python3
BuildRequires:  python3-curses
BuildRequires:  python3-lxml
BuildRequires:  python3-requests
BuildRequires:  python3-rpm
BuildRequires:  python3-setuptools
BuildRequires:  python3-termcolor
Requires:       sudo
Requires:       zypper
# rpm --import used curl but doesn't require it explicitly
Requires:       curl
Requires:       python3-curses
Requires:       python3-lxml
Requires:       python3-requests
Requires:       python3-rpm
Requires:       python3-termcolor
Requires:       zypper
# for rpm building and snap extracting
Requires:       rpm-build
Requires:       squashfs

%description
OBS Package Installer (CLI)
Search and install almost all packages available for openSUSE and SLE:
- openSUSE Build Service
- Packman
- Popular packages for 3rd party vendors

%prep
%setup -q

%build
./bin/opi --version
help2man -s8 -N ./bin/opi > opi.8
%pyproject_wheel

%install
%pyproject_install
install -m 644 -D -v org.openSUSE.opi.appdata.xml %{buildroot}%{_datadir}/metainfo/org.openSUSE.opi.appdata.xml
install -m 644 -D -v opi.8 %{buildroot}%{_datadir}/man/man8/opi.8
install -m 644 -D -v opi.default.cfg %{buildroot}%{_sysconfdir}/opi.cfg
%python3_fix_shebang
%fdupes %{buildroot}%{python3_sitelib}

%check

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_datadir}/metainfo/org.openSUSE.opi.appdata.xml
%{_datadir}/man/man8/opi.8%{?ext_man}
%{python3_sitelib}/*
%config %{_sysconfdir}/opi.cfg

%changelog
* Wed Mar 12 2025 Dominik Heidler <dheidler@suse.de>
- Version 5.8.1
  * Fix SyntaxWarning: invalid escape sequence '\s'
* Mon Feb 24 2025 Dominik Heidler <dheidler@suse.de>
- Version 5.8.0
  * Add mullvad-brower
* Sun Feb 16 2025 Dominik Heidler <dheidler@suse.de>
- Version 5.7.0
  * Add leap-only plugin to install zellij from github release
  * Don't use subprocess.run user kwarg on 15.6
  * Fix tests: Use helloworld-opi-tests instead of zfs
  * Perform search despite locked rpmdb
  * Simplify backend code
* Sat Feb  1 2025 Dominik Heidler <dheidler@suse.de>
- Use no macros in url in .spec for packtrack
* Thu Jan 23 2025 Dominik Heidler <dheidler@suse.de>
- Version 5.6.0
  * Add plugin to install vagrant from hashicorp repo
* Tue Jan 14 2025 Dominik Heidler <dheidler@suse.de>
- Version 5.5.0
  * Update opi/plugins/collabora.py
  * add collabora office desktop
  * Omit unsupported cli args on leap in 99_install_opi.py
  * Switch to PEP517 install
  * Fix 09_install_with_multi_repos_in_single_file_non_interactive.py
  * Fix 07_install_multiple.py on tumbleweed
  * Fix test suite on tumbleweed
  * Update available apps in opi - README.md
* Mon Nov  4 2024 Dominik Heidler <dheidler@suse.de>
- Version 5.4.0
  * Show key ID when importing or deleting package signing keys
  * Add option to install google-chrome-canary
* Fri Oct 25 2024 Dominik Heidler <dheidler@suse.de>
- Version 5.3.0
  * Fix tests for new zypper version
  * fix doblue slash in packman repo url
  * Add Plugin to install Libation
* Mon Jun 24 2024 Dominik Heidler <dheidler@suse.de>
- Version 5.2.1
  * Update freeoffice.py
* Tue Jun 11 2024 Dominik Heidler <dheidler@suse.de>
- Version 5.2.0
  * Add config option to reverse option order
* Fri Jun  7 2024 Dominik Heidler <dheidler@suse.de>
- Version 5.1.0
  * Use checkout@v4 for CI
  * Update issue templates
  * Increase prio from 90 to 70 for packman/openh264 repos
* Thu Mar 21 2024 pgajdos@suse.com
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang macro, [bsc#1212476]
* Thu Feb  1 2024 Dominik Heidler <dheidler@suse.de>
- Version 5.0.0
  * Allow selecting mirror 1st time when adding packman repo
  * Add Plugin for SoftMaker Freeoffice
  * Use new osc service run cmd syntax
  * Codecs: Install AV1 decoder for mpv
  * Bump .NET SDK plugin to .NET 8.0
* Tue Jan  2 2024 Dominik Heidler <dheidler@suse.de>
- Version 4.4.0
  * Match repos by alias when searching local repos
  * Rephrase OSS alternative hints
  * Fix typo in rpmbuild.py
* Fri Dec 15 2023 Dominik Heidler <dheidler@suse.de>
- Version 4.3.0
  * Hint open source alternatives
  * Fix issue with installing from existing openh264 repo
* Tue Dec 12 2023 Dominik Heidler <dheidler@suse.de>
- Version 4.2.0
  * Support multiple repos defined in a single .repo file
  * Automatically import packman key in non-interactive mode
  * Restructure code: Add classes for Repository, OBSPackage and LocalPackage
  * Hide package release for pkgs from local repos (same as with OBS pkgs)
  * Use tumbleweed repo for openh264 on Slowroll
  * Expand repovar $basearch (to e.g. x86_64 or aarch64)
* Thu Dec  7 2023 Dominik Heidler <dheidler@suse.de>
- Version 4.1.0
  * Add support for Slowroll
  * Replace $releasever also with ${releasever} syntax
  * Update changelog prefix to *
* Fri Nov 17 2023 Dominik Heidler <dheidler@suse.de>
- Version 4.0.0
  * Simplify rpmbuild by removing %%install
  * Add opi new dependencies to testsuite: rpm-build, squashfs
  * Rename rpmbuild internal dirs to uppercase
  * Fix building RPMs for Leap 15.5
  * Update opi-proxy .service file to listen on IPv6 as well
  * Add Snap library and Spotify plugin
  * Allow installing non-rpm applications (add OrcaSlicer)
  * chore: update multi_install description
  * Indent changes in changelog further than version
* Wed Oct 11 2023 Dominik Heidler <dheidler@suse.de>
- Version 3.6.0
- Increase timeouts in testsuite and improve output
- test: remove yandex-disk from multi-install test
- Run testsuite for (fake) MicroOS
- Fix repo URL generation for MicroOS and Leap Micro (fixes #158)
- Add multi package option
- Add ocenaudio audio editor (fixes #155)
- Ignore gpg check for unsigned pkgs (or pkgs without published key)
* Mon Sep 25 2023 Dominik Heidler <dheidler@suse.de>
- Version 3.5.0
- Expand releasever for local repo names
- Make resilio comment shorter
- Add option to skip plugins
- Update repo URL for MEGASync
* Wed Aug 30 2023 Dominik Heidler <dheidler@suse.de>
- Version 3.4.0
- Add unofficial Teams-for-linux client
- Improve non interactive tests
- Strip test module name
- chore: fix indentation
- docs: add config options, update opi help page
* Fri Jul 28 2023 Dominik Heidler <dheidler@suse.de>
- Version 3.3.0
- Add tests and tweak weighting algorithm for non interactive mode
- Allow running without user interaction
- Add config option to disable auto refresh
* Thu Jul 13 2023 Dominik Heidler <dheidler@suse.de>
- Version 3.2.0
- fix: add missing format string marks, remove empty lines
- Make release.sh more robust
* Tue Jul 11 2023 Dominik Heidler <dheidler@suse.de>
- Version 3.1.0
- Add MapTool RPM tool
* Mon Jun 19 2023 Dominik Heidler <dheidler@suse.de>
- Version 3.0.0
- Use best repo for each project (fixes #113)
- Use new rpm signing key for zoom (fixes #133)
- cleanup code
- Remove MS teams as it is discontinued
* Mon Apr  3 2023 Dominik Heidler <dheidler@suse.de>
- Version 2.17.0
- Codecs: Don't force ffmpeg>=5 on leap 15.5
- Use new checkout version in ci.yaml
* Mon Apr  3 2023 Dominik Heidler <dheidler@suse.de>
- Version 2.16.0
- dotnet: Install dotnet-sdk-7.0 (#124)
- Add jami p2p messenger plugin (#121)
* Sat Feb 18 2023 Dominik Heidler <dheidler@suse.de>
- Version 2.15.0
- Fix repo name encoding when asking for new key addition
* Mon Feb 13 2023 Dominik Heidler <dheidler@suse.de>
- Version 2.14.0
- Install openh264 according to arch
- Use http instead of https for openh264 repo
* Mon Feb 13 2023 Dominik Heidler <dheidler@suse.de>
- Version 2.13.0
- Add openh264 (#119)
* Mon Feb 13 2023 Dominik Heidler <dheidler@suse.de>
- Version 2.12.0
- Enforce ffmpeg>=5 on tumbleweed
* Mon Jan 30 2023 Dominik Heidler <dheidler@suse.de>
- Version 2.11.0
- Handle repos with multiple keys in key file (fixes #118)
* Thu Jan 26 2023 Dominik Heidler <dheidler@suse.de>
- Version 2.10.0
- Ask for submit in release.sh
- Fix packman plugin for 15.4
- Introduce repo key handling (bsc#1207334)
* Mon Jan  2 2023 Dominik Heidler <dheidler@suse.de>
- Version 2.9.0
- Install selected package explicitly from the selected repo
- Switch to resilio-sync for testsuite
- add resilio-sync
* Tue Aug  9 2022 Dominik Heidler <dheidler@suse.de>
- Version 2.8.0
- add anydesk
- add yandex browser
- Use list for plugin queries and check for conflicts
- Don't show projects with non-matching repo
* Mon Jun 13 2022 Dominik Heidler <dheidler@suse.de>
- Version 2.7.0
- Make repo parsing more stable and improve error handling
* Tue May 31 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Do not compress man page during build/install phase, but rather
  rely on the brp-scripts to pick the right compression format.
* Tue May 31 2022 Dominik Heidler <dheidler@suse.de>
- Version 2.6.0
- Move to global config in /etc/opi.cfg
- Check if desired repo is already added instead of relying on prefix
- Add config option use_releasever_var
* Mon May 16 2022 Dominik Heidler <dheidler@suse.de>
- Version 2.5.0
- Improve testsuite when ran locally
- Fix 01_install_from_packman.py test for leap
- Fix 02_install_from_home.py test for leap
- Run ci for both tumbleweed and leap
- Use $releasever in repo creation on Leap
- Run "osc up" in release.sh
* Mon Apr 25 2022 Dominik Heidler <dheidler@suse.de>
- Version 2.4.7
- Fix release script
- Fix numbering in --help
- Update README.md
- Add release helper script
* Fri Apr 22 2022 Dominik Heidler <dheidler@suse.de>
- Version 2.4.6
- Update .NET SDK to 6.0
* Tue Mar  1 2022 Dominik Heidler <dheidler@suse.de>
- Version 2.4.5
- Packman codec changes
* Fri Jan 28 2022 Dominik Heidler <dheidler@suse.de>
- Version 2.4.4
- Fix for Alpha/Beta dist versions (boo#1195206)
* Mon Jan 24 2022 Dominik Heidler <dheidler@suse.de>
- Version 2.4.3
- Fix for tumbleweed based MicroOS
* Mon Oct 25 2021 Dominik Heidler <dheidler@suse.de>
- Version 2.4.2
  * Changed
  - Switched to opensuse provided opi proxy
* Mon Oct 11 2021 Dominik Heidler <dheidler@suse.de>
- Version 2.4.1
  * Changed
  - Don't expect output to be a tty
* Mon Oct 11 2021 Dominik Heidler <dheidler@suse.de>
- Version 2.4.0
  * Added
  - Scrolling of results
  - Plugin for atom editor
* Mon Sep  6 2021 Dominik Heidler <dheidler@suse.de>
- Version 2.3.0
  * Changed
  - Fixed gpgcheck entry in add_repo()
  - Allowed using multiple query keywords that are combined using AND
  * Added
  - Plugin for sublime text
  - Plugin for yandex-disk
* Fri Aug 20 2021 Dominik Heidler <dheidler@suse.de>
- Version 2.2.0
  * Added
  - Plugin for MEGA
  - Plugin for Edge Beta
  - Argument parser with option for reverse output order
* Tue Aug 10 2021 Dominik Heidler <dheidler@suse.de>
- Version 2.1.1
  * Added
  - Plugin for Brave Browser
* Tue Jul  6 2021 Dominik Heidler <dheidler@suse.de>
- Version 2.1.0
  * Added
  - Support for dnf backend
  * Changed
  - Deduplicated packman repo creation code
* Mon May  3 2021 Dominik Heidler <dheidler@suse.de>
- Version 2.0.0
  * Added
  - Automated tests
  - Extensible Plugin interface for plugins (eg. this one)
  - Added plugins for chrome, dotnet, edge, teams, packman, plex,
    skype, slack, teamviewer, vivaldi, vscode, vscodium, zoom
  * Changed
  - Rewrote the complete tool in python3
* Fri Apr 16 2021 Dirk Müller <dmueller@suse.com>
- stop owning dirs provided by filesytem rpm (bsc#1184786)
* Sun Jan 17 2021 Yunhe Guo <i@guoyunhe.me>
- Version 0.10.0
  * Added
  - Microsoft Teams installer
  - Warning for personal repository
* Sun Nov  1 2020 Yunhe Guo <i@guoyunhe.me>
- Fix appstream file location
* Sat Oct  3 2020 Yunhe Guo <i@guoyunhe.me>
- Version 0.9.0
  * Added
  - Help (-h, --help) and version (-v, --version) option
  * Changed
  - Filter out -devel, -docs and -lang packages
  - Don't show i586 packages on x86_64 system
* Sat Jul 25 2020 Yunhe Guo <i@guoyunhe.me>
- Version 0.8.3
  * Fixed
  - ffmpeg/libav packages due to Packman update
* Sat May 16 2020 Yunhe Guo <i@guoyunhe.me>
- Version 0.8.2
  * Fixed
  - Ghost process on XML parsing failure
* Fri Apr  3 2020 Yunhe Guo <i@guoyunhe.me>
- Version 0.8.1
  * Fixed
  - OBS limit error when searching php, test, etc.
* Sat Feb 29 2020 Yunhe Guo <i@guoyunhe.me>
- Version 0.8.0
  * Changed
  - Type number 0 to exit
* Fri Nov  8 2019 Yunhe Guo <i@guoyunhe.me>
- Version 0.7.1
  * Fixed
  - Missing use File::Temp;
* Thu Aug 29 2019 Yunhe Guo <i@guoyunhe.me>
- Version 0.7.0
  * Changed
  - Force repo URL to HTTPS
  * Fixed
  - Ctrl + C handling of spinner
* Sun Aug 18 2019 Yunhe Guo <i@guoyunhe.me>
- Version 0.6.0
  * Added
  - Search spinner
  * Fixed
  - Packman repo doesn't have *.repo file
  - Long version numbers are cutted
* Sun Aug 18 2019 Yunhe Guo <i@guoyunhe.me>
- Added perl(LWP::Protocol::https) dependency and change to more
  compatible dependency format
* Tue Jun 11 2019 Yunhe Guo <i@guoyunhe.me>
- Version 0.5.2
  * Fixed
  - Trim "NAME" and "VERSION" string
* Mon Jun  3 2019 Yunhe Guo <i@guoyunhe.me>
- Version 0.5.1
  * Fixed
  - Fix dependency not found issue
* Wed May 22 2019 Yunhe Guo <i@guoyunhe.me>
- Version 0.5.0
  * Added
  - API proxy server to prevent hard-coded passwords in the script
* Tue May 21 2019 Yunhe Guo <i@guoyunhe.me>
- Version 0.4.0
  * Added
  - PMBS (Packman Build Service) support
* Thu May  9 2019 Yunhe Guo <i@guoyunhe.me>
- Version 0.3.1
  * Fixed
  - `opi opi` cannot find `opi`
* Thu May  9 2019 Yunhe Guo <i@guoyunhe.me>
- Version 0.3.1
  * Fixed
  - Remove quotes from version number. So Leap and SLE can search packages.
* Wed May  8 2019 Yunhe Guo <i@guoyunhe.me>
- Version 0.3.0
  * Added
  - Support SLE
  * Changed
  - Better print column alignment
* Fri May  3 2019 Yunhe Guo <i@guoyunhe.me>
- Version 0.2.0
  * Added
  - Install Packman Codecs with `opi packman` or `opi codecs`
  - Install Skype with `opi skype`
  - Install VS Code with `opi vs code`
* Mon Apr 29 2019 Yunhe Guo <i@guoyunhe.me>
- Version 0.1.2
  * Fixed
  - Fixed lost of "noarch" packages
  - Be able to search with dashes in keywords
* Mon Apr 29 2019 Yunhe Guo <i@guoyunhe.me>
- Version 0.1.1
  * Fixed
  - Removed XML dump which may cause problems.
* Sun Apr 28 2019 Yunhe Guo <i@guoyunhe.me>
- Version 0.1.0
  * Added
  - Search packages from OBS
  - List properly sorted search result
  - Use different colors for official, experimental and personal projects
  - Choose package and install
  - Keep or remove repository after installation
